// 
// Module: CompactTablePixelIterator
// Author: Hassan Siddiqui
//
// Description: 
//
// Class representation of an iterator that handles DAL-based maps
// in a table format, but data are stored in such a way that a single row may
// represent one or many pixels.
//
// NOTE: This class assumes that
// a) There is a special row of int16-type that describes the number of pixels
// per row.
// b) y-values in pixel set of a given row goes as y0 +
// (N-1), where N is the number of pixels, y0 is the initial value
// stored in that row.
//
// Modifications: See ChangeLog
// 
// $Id: CompactTablePixelIterator.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef CompactTablePIXELITERATOR_H
#define CompactTablePIXELITERATOR_H

// General classes
#include <iostream>

// SAS-specific classes
#include "Xmm.h"
#include "Dal.h"

// General utility functions
#include "errstr.h"
#include "Tracer.h"

// Local classes
#include "PixelIterator.h"
#include "WCSConvertor.h"
#include "PixelElement.h"
#include "PositionUtils.h"

class CompactTablePixelIterator : public PixelIterator
{
public:

  /* Constructors */
  CompactTablePixelIterator( const string & tablename,
		      const string & xcolname,
		      const string & ycolname,
		      const string & valuecolname,
		      const string & countername);
  
  /* Destructors */
  ~CompactTablePixelIterator();

  /* Iterator methods */
  void first ();
  void next  ();
  bool isDone();
  PixelElement currentItem();

  unsigned  xbins() const;

  /* The total number of elements in map */
  unsigned size()   const;

  /* WCSConvertor object */
  const WCSConvertor * wcsconvertor() const;


private:

  /* Disallow default constructor */
  CompactTablePixelIterator();

  bool _firstcalled;

  unsigned _ccdid;

  unsigned long _index;

  unsigned long _xindexsize;
  unsigned long _yindexsize;

  unsigned long _tableelements;

  DataSet    * _set;

  Table      * _table;

  Column     * _xColumn;
  Column     * _yColumn;
  Column     * _valueColumn;
  Column     * _counterColumn;
  
  ColumnData * _xColData;
  ColumnData * _yColData;
  ColumnData * _valueColData;
  ColumnData * _counterColData;
  
  int16      * _xData;
  int16      * _yData;
  int16      * _valueData;
  int16      * _counterData;

  vector<int16> _tempcounter;

  WCSConvertor * _wcsconv;

  const PositionUtils *  _putils;
  vector<double> _detPixWidths;

  /* Data are compacted such that 1 row in input table corresponds to one or
many pixels. Track these using a counter */
  int        _pixelcounter;
  int        _pixelcounterlimit;
};

#endif
