// 
// Module: DummyMOSCoreData
// Author: Hassan Siddiqui
//
// Description: 
// Dummy MOS Instrument-specific data/methods for arf generation.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: DummyMOSCoreData.cc,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

/* General */

/* SAS-specific */
#include "Xmm.h"
#include "Tracer.h"

/* Local classes */
#include "DummyMOSCoreData.h"
#include "SimpleIterator.h"
#include "DummySplitEventsData.h"
#include "NullSplitEventsData.h"
#include "NonUnifBinnedAxis.h"

/*  Constructors */
DummyMOSCoreData::DummyMOSCoreData( Xmm::Instrument /* instrumentID */) 
    {

      _sourcePosition = new SourcePosition(0,0,0,0);

      _psf = new PsfModel (0, 0, 120, 10);

//        if (usesplits)
//  	{
//  	  _splitEventsData = new DummySplitEventsData(4, splitEventsFile);
//  	}
//        else
	{
	  _splitEventsData = new NullSplitEventsData(4);
	}

      _patternData = new MOSPatternData(*_splitEventsData);
    };

  /*  Destructors */
DummyMOSCoreData::~DummyMOSCoreData()
{
  PROC;
  delete _patternData; _patternData = 0;
  delete _splitEventsData; _splitEventsData = 0;
  delete _psf; _psf = 0;
  delete _sourcePosition; _sourcePosition = 0;
  ENDPROC;
};
  
const BinnedAxis * DummyMOSCoreData::ebins() const
{
  PROC;
  IntervalVector<double> iv;
  iv.push_back(Bin(0, 15));
  RETURN new NonUnifBinnedAxis(iv);
}

bool DummyMOSCoreData::setCcd(const CamCoords & /* camcoords */)
{
  PROC;
  RETURN true;
}

unsigned int DummyMOSCoreData::ccdFirst() const {PROC; RETURN 1;}
unsigned int DummyMOSCoreData::ccdLast() const {PROC; RETURN 1;}

const PatternData & DummyMOSCoreData::patternData() const
{
  PROC;
  RETURN *_patternData;
}

/* Return source position */
const SourcePosition * DummyMOSCoreData::sourcePosition() const
{ PROC; RETURN _sourcePosition; }

const PsfModel * DummyMOSCoreData::psf() const
{ PROC; RETURN _psf; }

/* Convert from DETX/DETY (0.05 arcsec units) to camcoord2 */
const CamCoords DummyMOSCoreData::detxy005ToCamCoord2( 
						      int /* detx_005 */, 
						      int /* dety_005 */) const
{
  PROC;
  RETURN CamCoords( 0, 0, 0);
}

/* Convert from CAMCOORD2 to PIXCOORD */
const PixCoords DummyMOSCoreData::camCoord2ToPixCoord( const CamCoords & /* camcoords */ ) const
{
  PROC;
  RETURN PixCoords( 0, 0 );
}

/* Pixel size, in arcsecs */
double DummyMOSCoreData::pixelSize()          const
{
  PROC;
  RETURN 1.0;
};

/* Frame period, in seconds */
double DummyMOSCoreData::framePeriod()          const
{
  PROC;
  RETURN 1.0;
};


/* Iterator methods. */

GeneralIterator<int> * DummyMOSCoreData::ccdIterator()
{
  PROC;
  const int CCD_FIRST  = 0;
  const int CCD_LAST   = 6;
  RETURN (new SimpleIterator<int>(CCD_FIRST, CCD_LAST));
}

GeneralIterator<int> * DummyMOSCoreData::xpixelIterator() const
{
  PROC;
  const int X_PIXEL_LOW  = 0;
  const int X_PIXEL_HIGH = 10;
  RETURN (new SimpleIterator<int>(X_PIXEL_LOW, X_PIXEL_HIGH));
}

GeneralIterator<int> * DummyMOSCoreData::ypixelIterator() const
{
  PROC;
  const int Y_PIXEL_LOW  = 0;
  const int Y_PIXEL_HIGH = 10;
  RETURN (new SimpleIterator<int>(Y_PIXEL_LOW, Y_PIXEL_HIGH));
}

/* Data resource methods */

/* Mirror area, in cm2 */
double DummyMOSCoreData::effectiveArea      (double /* energy */) const
{
  PROC;
  RETURN 3000.0;
}

  double DummyMOSCoreData::quantumEfficiency  (double /* x */, 
					       double /* y */, 
					       double /* energy */) const
{
  PROC;
  RETURN 1.;
}

double DummyMOSCoreData::filterTransmission (double /* x */, 
					     double /* y */, 
					     double /* energy */) const
{
  PROC;
  RETURN 1.;
}

double DummyMOSCoreData::gratingAttenuation( double /* energy */) const
{
  PROC;
  RETURN 1.;
}
