// This  skeleton file was automatically created by 
//            pkgmaker 0.1
//            Thursday, December 11 1997
// 
// Module: DummyMOSCoreData
// Author: Hassan Siddiqui
//
// Description: Dummy MOS Instrument-specific data/methods for arf generation.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: DummyMOSCoreData.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef DummyMOSCoreData_H
#define DummyMOSCoreData_H

// General classes
#include <iostream>

// SAS-specific classes
#include "Xmm.h"

// General utility functions

// Local classes
#include "CoreData.h"
#include "MOSPatternData.h"
#include "SplitEventsData.h"

class DummyMOSCoreData : public CoreData
{
public:

  /*  Constructors */
  DummyMOSCoreData( Xmm::Instrument instrumentID
		    /* , bool usesplits
		       , const string & splitEventsFile */);

  /*  Destructors */
  ~DummyMOSCoreData();

  const BinnedAxis * ebins() const;

  bool setCcd( const CamCoords & camcoords);

  unsigned int ccdFirst() const;
  unsigned int ccdLast() const;

  const PatternData & patternData() const;

  /******************************************************
   * 
   * Geometry based routines
   *
   ******************************************************/

  /* Get source position */
  const SourcePosition * sourcePosition() const;
  const PsfModel * psf() const;

  /* Convert from DETX/DETY (0.05 arcsec units) to camcoord2 */
  const CamCoords detxy005ToCamCoord2( int detx_005, 
				       int dety_005) const;

  /* Convert from CAMCOORD2 to PIXCOORD */
  const PixCoords camCoord2ToPixCoord( const CamCoords & camcoords ) const;

  /* Pixel size, in arcsecs */
  double pixelSize()          const;

  /* Frame period, in seconds */
  double framePeriod()          const;

  /* Iterator methods. */
  GeneralIterator<int> * ccdIterator();

  GeneralIterator<int> * xpixelIterator() const;

  GeneralIterator<int> * ypixelIterator() const;

  /* Data resource methods */

  /* Return spatial density (/sq.pixel) 
   * as a function of offset with respect
   * to source position */
//    double spatialFunction    (PolCoord offset, 
//  			     double energy) const;

  /* Mirror area, in cm2 */
  double effectiveArea      ( double  energy ) const;

  double quantumEfficiency  ( double  x, 
			      double  y, 
			      double  energy ) const;

  double filterTransmission (double x, 
			     double y, 
			     double energy) const;

  double gratingAttenuation(double energy) const;

private:

  /* Update state of object as a 
   * consequence of ccd number changing */
  void updateCCD();

  /* PatternData object. 
   * This is common to both CAL- and Dummy implementations, 
   * so might need to move this to a MOS-specific parent class
   */
  MOSPatternData *  _patternData;

  /* Use a dummy split events data instance */
  SplitEventsData * _splitEventsData;

  SourcePosition * _sourcePosition;

  PsfModel * _psf;
};
#endif
