//
// Module: IterEeCorrector
// Author: Hassan Siddiqui
//
// Description: 
//
// Returns a set of encircled energy correction factors
//
// Modifications: See ChangeLog
// 
// $Id: IterEeCorrector.cc,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

/* General */

/* SAS-specific */
#include "Tracer.h"

/* Local */
#include "IterEeCorrector.h"
#include "Interpolator.h"


/* Constructor */
IterEeCorrector::IterEeCorrector(unsigned eefactor):
  _eefactor(eefactor)
{
  PROC;
  ENDPROC;
}

/* Destructor */
IterEeCorrector::~IterEeCorrector()
{
  PROC;
  ENDPROC;
}

vector<double> 
IterEeCorrector::Fraction( const vector<double> & energyvector) const
{
  PROC;

  vector<double> eevector;
  vector<unsigned> eindexvector;
  unsigned sz = energyvector.size();

  for (unsigned i = 0; i < sz; i += _eefactor)
    {
      errstr << " Computing EE fraction for energy " 
	     << energyvector[i]
	     << " ..."
	     << Sas::message(Msg::App, Msg::Verbose);

      eevector.push_back( eeFraction(energyvector[i]) );
      eindexvector.push_back(i);
    }

  eevector.push_back( eeFraction(energyvector[ sz - 1 ]) );
  eindexvector.push_back( sz - 1 );

  /* Interpolate data */
  vector<double> factors;

  errstr 
    << "IterEeCorrector: Interpolating data..."
    << Sas::message(Msg::App, Msg::Verbose);

  unsigned r_index0 = 0;
  for (unsigned i = 0; i < energyvector.size(); ++i)
    {
      while ( i > eindexvector[r_index0+1] )
	{
	  r_index0++;
	}
            
      /* Get ee fraction values for these points */
      double f0   = eevector[r_index0];
      unsigned i0 = eindexvector[r_index0];
      double f1   = eevector[r_index0+1];
      unsigned i1 = eindexvector[r_index0+1];

      /* Now interpolate */
      double interp_ee= 
	f0 + (double(i-i0)) * (f1-f0) / double(i1-i0);

      errstr 
	<< " i " << i
	<< " i0 " << i0
	<< " i1 " << i1
	<< " f0 " << f0
	<< " f1 " << f1
	<< " _eefactor " << _eefactor
	<< " interp_ee " << interp_ee
	<< Sas::message(Msg::App, Msg::Noisy);


      /* Fill the factors array */
      factors.push_back(interp_ee);
    }

  errstr 
    << "IterEeCorrector: Interpolation COMPLETE."
    << Sas::message(Msg::App, Msg::Verbose);

  
  RETURN factors;
}
