//
// Module: OffCCDPixelIterator
// Author: Hassan Siddiqui
//
// Description:
//
// Class representation of an iterator that handles DAL-based maps
// in table format.
//
// Modifications: See ChangeLog
//
// $Id: OffCCDPixelIterator.h,v 1.5 2009/09/03 13:19:51 aibarra Exp $

#ifndef TABLEPIXELITERATOR_H
#define TABLEPIXELITERATOR_H

// General classes
#include <iostream>

// SAS-specific classes
#include "Dal.h"
#include "Region.h"

// General utility functions
#include "errstr.h"
#include "Tracer.h"

// Local classes
#include "PixelIterator.h"
#include "WCSConvertor.h"
#include "PixelElement.h"
#include "RegionExtent.h"
#include "PositionUtils.h"


class OffCCDPixelIterator : public PixelIterator
{
public:

  /* Constructors */
  OffCCDPixelIterator(PixelIterator * BSPixelIt,
                   const PositionUtils * const putils, unsigned long flags,
                   bool ignoreoutoffov, unsigned long ccdmask);

  /* Destructors */
  ~OffCCDPixelIterator();

  /* Iterator methods */
  void first ();
  void next  ();
  bool isDone();
  PixelElement currentItem();

  const WCSConvertor * wcsconvertor() const;

  unsigned  xbins() const;

  /* The total number of elements off CCD */
  unsigned size()   const;

  /* The total number of detector pixels in input region */
  unsigned totalPixels()   const;

private:

  bool _firstcalled;

  unsigned long _index;
  unsigned long _offccdelements;
  unsigned long _totalelements;

  const PositionUtils *  _putils;
  vector<double> _detPixWidths;

  WCSConvertor * _wcsconv;

  /* Camera coordinates of pixels lying within source area and on chip gap */
  vector<PixelElement> _OffCCDPixel;

  /* The width of elements in the grid used to determine points off
     the CCD (in detector pixels) */
  float _gridWidth;
};

#endif
